C--------------------------------------------------------------------
C The user of the OPEN-ADAS system and data (hereinafter "the User")
C accepts the following terms and conditions: 
C 
C   1. The University of Strathclyde uses all reasonable endeavours
C      to ensure the accuracy of the data provided and any
C      information given, but the University makes no warranty,
C      expressed or implied as to its accuracy, integrity, fitness
C      for purpose and shall not be responsible for the use to
C      which the data is put by the User and/or any consequences
C      arising out of any inaccuracies or omissions.
C 
C   2. Any downloaded OPEN-ADAS file is made available here for the
C      personal use of the User only.  It must not be used for any
C      commercial application, incorporated into any web site or in
C      any form re-distributed without express prior written
C      permission from the ADAS Project. In particular, but not by
C      way of limitation, it must not be:
C 
C        * inserted into a managed database structure
C        * redistributed along with a modelling or analysis code
C        * made available on a public website.
C 
C Permission for OPEN-ADAS data incorporation in non-commercial
C code/system development for scientific advance will not be
C unreasonably withheld, but will be subject to written agreement
C on a case by case basis.
C 
C The User will indemnify the University of Strathclyde and keep
C it fully and effectively indemnified against each and every
C claim made against the University as a result of the User's
C use of the data.  
C--------------------------------------------------------------------
       PROGRAM TEST
       
       IMPLICIT NONE
C------------------------------------------------------------------------
C  Purpose:
C          Test the XXDATA_21 routine and also provide a brief
C          example of its use.
C
C  Explanaton:
C          This program is distributed as part of the ADAS
C          subroutine library either via direct CVS to ADAS Project
C          members or via download by OPEN-ADAS users. It reads a
C          file called "test.dat" (distributed along with this
C          program) and prints out some of the contents. The
C          program is intended to serve as an example of using the
C          XXDATA_21 subroutine as well as testing it. A short
C          shell script called "test.sh" is used to compile and
C          test the code.
C
C  Variables:
C          All variables are documented by XXDATA_21. See either the
C          Fortran source or the PDF documentation for the routine.
C          Variables not passed into XXDATA_21 are trivial in nature.
C
C  Routines:
C          Routine    Source    Brief description
C          -------------------------------------------------------------
C          XXDATA_21  ADAS      Read complete data from an ADF21 file
C
C  Author : Allan Whiteford
C
C  Date   : 11/01/08
C       
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Parameters required by XXDATA_21
C     --------------------------------        
      INTEGER     MXBE      , MXTD         , MXTT
      PARAMETER ( MXBE = 25 , MXTD = 25    , MXTT = 25 )
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Input variables (i.e. non-parameter) required by XXDATA_21
C     ----------------------------------------------------------
      INTEGER   IUNIT
      CHARACTER*80 DSNIN     
C-----------------------------------------------------------------------		

C-----------------------------------------------------------------------
C     Output variables required by XXDATA_21
C     --------------------------------------
      CHARACTER*2         TSYM
      INTEGER             ITZ,         NBE,         NTDENS,      NTTEMP
      REAL*8              BE(MXBE),    BEREF,       SVED(MXBE,MXTD)
      REAL*8              SVREF,       SVT(MXTT),   TDENS(MXTD), TDREF
      REAL*8              TTEMP(MXTT), TTREF
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Variables only used by this test program
C     ----------------------------------------
      INTEGER   I,J,K
C----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Open input file for reading
C     ---------------------------      
      IUNIT = 10
      DSNIN='test.dat'
      OPEN(UNIT = IUNIT , FILE=DSNIN , STATUS = 'OLD')
C-----------------------------------------------------------------------
       
C-----------------------------------------------------------------------
C     Pass unit number and dimension parameters to XXDATA_21 and
C     get back contents of file.
C     --------------------------      

      CALL XXDATA_21( IUNIT  , MXBE   , MXTD   , MXTT   ,
     &                ITZ    , TSYM   , BEREF  , TDREF  ,
     &                TTREF  , SVREF  , NBE    , BE     ,
     &                NTDENS , TDENS  , NTTEMP , TTEMP  ,
     &                SVT    , SVED   , DSNIN
     &              )
C-----------------------------------------------------------------------
   
C-----------------------------------------------------------------------
C     Print out some of the contents to screen
C     ----------------------------------------

      PRINT *,'XXDATA_21 Test Program'      
      PRINT *,'----------------------'
      PRINT *,' '
      PRINT *,'The following is some information about the'
      PRINT *,'input file: '//DSNIN
      PRINT *,' '       
      PRINT *,'Reference parameters:'
      PRINT *, ' ( Energy Temperature Density) = '
      PRINT *, '         ( ',BEREF,TTREF,TDREF, ' )'
      PRINT *,' '       
      PRINT *,'Temperature Grid'
      PRINT *, (TTEMP(I),I=1,NTTEMP)
      PRINT *,' '       
      PRINT *,'Energy Grid'
      PRINT *, (BE(I),I=1,NBE)
      PRINT *,' '       
      PRINT *,'Density Grid'
      PRINT *, (TDENS(I),I=1,NTDENS)
      PRINT *,' '       
      PRINT *,'BMS coefficient at reference temperature'
      PRINT *,'for density 5 and energy 7'
      PRINT *, SVED(7,5)
      PRINT *,' '       
      PRINT *,'BMS coefficient at reference energy/density'
      PRINT *,'for temperature 9'
      PRINT *, SVT(9)
C-------------------------------------------------------------------

      END					  	
